@@ -20,7 +20,7 @@ class Server:
         self.abs_cwd, self.jar = os.path.split(self.jar)
         if not os.path.isabs(self.abs_cwd):
             self.abs_cwd = os.path.join(os.getcwd(), self.abs_cwd)
-
+        os.remove(os.path.join(self.abs_cwd, self._log))
         try:
             file = open(os.path.join(self.abs_cwd, self._log), 'r+')
         except FileNotFoundError:
@@ -32,12 +32,8 @@ class Server:
         self.sterr = file if stdout is None else stderr
         self.stdin = subprocess.PIPE
 
-    def online(self):
-        return True if self.process.returncode is None else False
-
     def _kill_conflicting_procs(self):
         if os.path.exists(os.path.join(self.abs_cwd, self._log)):
-            os.remove(os.path.join(self.abs_cwd, self._log))
             with open(os.path.join(self.abs_cwd, self._log), 'w') as file:
                 pass
         for proc in psutil.process_iter():
